BufferMemoryAllocator

Struct BufferMemoryAllocator 

pub struct BufferMemoryAllocator<'a>(/* private fields */);
A class that does simple allocation based on a size and returns the pointer to the memory address. It bookmarks a buffer with certain size. The allocation is simply checking space and growing the cur_ pointer with each allocation request.

Implementations

Source

impl<'a> BufferMemoryAllocator<'a>

pub fn new(buffer: &'a mut [u8]) -> Self

Constructs a new memory allocator using a fixed-size buffer.

Arguments
  • buffer - The buffer to use for memory allocation.
Panics

Panics if the buffer is larger than u32::MAX bytes.