pub struct BufferMemoryAllocator<'a>(/* private fields */);Expand description
A class that does simple allocation based on a size and returns the pointer to the memory address. It bookmarks a buffer with certain size. The allocation is simply checking space and growing the cur_ pointer with each allocation request.
Implementations